# -*- coding: utf-8 -*-

from em_tasks.store.models import StoreSeller


class SkuParser():
  supported_marketplaces = ['US', 'CA', 'MX', 'UK', 'DE', 'FR', 'IT', 'ES', 'JP', 'TR']
  _store_sellers = None
  source_codes = {
    'X01': 'Rakuten',
    'X02': 'Ebay_US',
    'X03': 'Coupang',
    'X04': 'AMZ_JP',
    'X05': 'AMZ_UK',
    'X06': 'AMZ_US',
    'X07': 'AMZ_TR',
    'X08': 'AMZ_DE',
    'X10': 'Naver',
    'X11': 'www_books_com_tw',
    'X12': 'Ebay_UK',
    'X95': 'Dangdang',
    'X98': 'COCOONCENTER',
    'X99': 'AROMA_ZEN',
    'RAKUTEN': 'Rakuten',
    'EBAY_US': 'Ebay_US',
    'EBAY_UK': 'Ebay_UK',
    'COUPANG': 'Coupang',
    'AMZ_JP': 'AMZ_JP',
    'AMZ_UK': 'AMZ_UK',
    'AMZ_US': 'AMZ_US',
    'AMZ_TR': 'AMZ_TR',
    'AMZ_DE': 'AMZ_DE',
    'NAVER': 'Naver',
    'AROMA_ZEN': 'AROMA_ZEN',
    'COCOONCENTER': 'COCOONCENTER',
    'DANGDANG': 'Dangdang',
    'EM': 'EMP'
  }

  @classmethod
  def has_store_seller(cls, store_seller_id):
    if cls._store_sellers is None:
      cls._store_sellers = dict()
      for store_seller in StoreSeller.select().execute():
        formatted_ssid = "0:0>10".format(store_seller.id)
        cls._store_sellers[formatted_ssid] = None

    return store_seller_id in cls._store_sellers

  @classmethod
  def parse(cls, sku):
    seller_id = source = source_product_id = None
    sku_u = sku.upper().replace('-', '_')
    parts = sku_u.split('_')
    for code, src in cls.source_codes.items():
      if sku_u.startswith(code):
        source = src
        if src in ['Naver', 'Coupang']:
          if len(parts) > 2:
            source_product_id = parts[-2]
          else:
            source_product_id = parts[-1]
        elif src == 'EM':
          source_product_id = sku
        else:
          source_product_id = parts[-1]

        break

    if not source:
      if sku_u.startswith('AMZ_'):
        source_product_id = parts.pop()

        marketplace = None
        for part in parts:
          if part in cls.supported_marketplaces:
            marketplace = part
            break
        if not marketplace:
          marketplace = 'US'
        source = 'AMZ_{}'.format(marketplace)
      else:
        source = 'Other'
        source_product_id = sku

    if len(parts) >= 3:
      sku_seller_id = parts[1]
      if cls.has_store_seller(sku_seller_id):
        seller_id = sku_seller_id

    return (seller_id, source, source_product_id)
